pub struct CompositeSolid {
pub id: ArtifactId,
pub consumed: bool,
pub sub_type: CompositeSolidSubType,
pub output_index: Option<usize>,
pub solid_ids: Vec<ArtifactId>,
pub tool_ids: Vec<ArtifactId>,
pub code_ref: CodeRef,
pub composite_solid_id: Option<ArtifactId>,
pub pattern_ids: Vec<ArtifactId>,
}Fields
id: ArtifactIdconsumed: boolWhether this artifact has been used in a subsequent operation
sub_type: CompositeSolidSubTypeoutput_index: Option<usize>Index of this output in the expression result, for operations that return multiple selectable bodies from one KCL variable.
solid_ids: Vec<ArtifactId>Constituent solids of the composite solid.
tool_ids: Vec<ArtifactId>Tool solids used for asymmetric operations like subtract.
code_ref: CodeRefcomposite_solid_id: Option<ArtifactId>This is the ID of the composite solid that this is part of, if any, as a composite solid can be used as input for another composite solid.
pattern_ids: Vec<ArtifactId>Pattern operations that use this composite solid as their source.