#[repr(C)]pub struct Point4d<T = f32> {
pub x: T,
pub y: T,
pub z: T,
pub w: T,
}Expand description
A point in homogeneous (4D) space
Fields
x: Ty: Tz: Tw: TImplementations
Sourceimpl<T> Point4d<T>
impl<T> Point4d<T>
Sourcepub fn map<U, F>(self, f: F) -> Point4d<U>where
F: FnMut(T) -> U,
pub fn map<U, F>(self, f: F) -> Point4d<U>where
F: FnMut(T) -> U,
Takes some closure, and calls it on each component of this point.
Examples
use kcl_api::point::Point4d;
let p0 = Point4d {
x: 1.0,
y: 1.0,
z: 1.0,
w: 1.0,
};
assert_eq!(
p0.map(|n| n * 2.0),
Point4d {
x: 2.0,
y: 2.0,
z: 2.0,
w: 2.0
}
);Trait Implementations
impl<T: Copy> Copy for Point4d<T>
Sourceimpl<'de, T> Deserialize<'de> for Point4d<T>where
T: Deserialize<'de>,
impl<'de, T> Deserialize<'de> for Point4d<T>where
T: Deserialize<'de>,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<T: JsonSchema> JsonSchema for Point4d<T>
impl<T: JsonSchema> JsonSchema for Point4d<T>
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl<T> Freeze for Point4d<T>where
T: Freeze,
impl<T> RefUnwindSafe for Point4d<T>where
T: RefUnwindSafe,
impl<T> Send for Point4d<T>where
T: Send,
impl<T> Sync for Point4d<T>where
T: Sync,
impl<T> Unpin for Point4d<T>where
T: Unpin,
impl<T> UnsafeUnpin for Point4d<T>where
T: UnsafeUnpin,
impl<T> UnwindSafe for Point4d<T>where
T: UnwindSafe,