Path

Struct Path 

pub struct Path {
Show 15 fields pub id: ArtifactId, pub sub_type: PathSubType, pub plane_id: ArtifactId, pub seg_ids: Vec<ArtifactId>, pub consumed: bool, pub sweep_id: Option<ArtifactId>, pub trajectory_sweep_id: Option<ArtifactId>, pub solid2d_id: Option<ArtifactId>, pub code_ref: CodeRef, pub composite_solid_id: Option<ArtifactId>, pub sketch_block_id: Option<ArtifactId>, pub origin_path_id: Option<ArtifactId>, pub inner_path_id: Option<ArtifactId>, pub outer_path_id: Option<ArtifactId>, pub pattern_ids: Vec<ArtifactId>,
}

Fields

id: ArtifactIdsub_type: PathSubTypeplane_id: ArtifactIdseg_ids: Vec<ArtifactId>consumed: bool

Whether this artifact has been used in a subsequent operation

sweep_id: Option<ArtifactId>

The sweep, if any, that this Path serves as the base path for. corresponds to path_id on the Sweep.

trajectory_sweep_id: Option<ArtifactId>

The sweep, if any, that this Path serves as the trajectory for.

solid2d_id: Option<ArtifactId>code_ref: CodeRefcomposite_solid_id: Option<ArtifactId>

This is the ID of the composite solid that this is part of, if any, as this can be used as input for another composite solid.

sketch_block_id: Option<ArtifactId>

For sketch paths, the ID of the sketch block this path was created from. None for region paths and paths created in other ways.

origin_path_id: Option<ArtifactId>

For region paths, the ID of the sketch path this region was created from. None for sketch paths.

inner_path_id: Option<ArtifactId>

The hole, if any, from a subtract2d() call.

outer_path_id: Option<ArtifactId>

The Path that this is a hole of, if any. The inverse link of inner_path_id.

pattern_ids: Vec<ArtifactId>

Pattern operations that use this path as their source.